/** AgentHT00000X.java
 * -*- java -*-
 *
 * RCS: $Id: AgentHT00000X.java,v 1.3 2005/02/16 03:55:57 kanmy Exp kanmy $
 *
 * RCS: $Log: AgentHT00000X.java,v $
 * RCS: Revision 1.3  2005/02/16 03:55:57  kanmy
 * RCS: Added additional method to print the board and debugging variables and
 * RCS: constants.
 * RCS:
 * RCS: Revision 1.2  2005/02/08 01:24:05  kanmy
 * RCS: Corrected bug that transposed x and y during board read-in.
 * RCS:
 */

import java.io.*;
import java.util.Random;
import java.util.Timer;
import java.util.TimerTask;

public class AgentHT00000X {

    static final String tagline = "Games are boring to play but game players are challenging to code!";
    static final String email = "u0000000@nus.edu.sg";

    static final int MOVE = 1;	// modes of operation
    static final int EMAIL = 2;
    static final int TAGLINE = 3;
    static final int UNKNOWN = -1;

    static final int URGENT_TIME = 2800; // when do we consider we are out of time?
    static final String URGENT_MOVE = "3 3"; // the default move if we run out of time

    static final int DEBUG = 1;
    static final int NO_DEBUG = 2;
    
    char[][] board = null;	// the board as an array of characters
    int rows = -1;		// the dimension of the board
    int cols = -1;
    int debug = NO_DEBUG;
    int turnNumber = -1;	// which turn number
    int mySymbol = -1;		// who am I playing?
    String tmpfile = "";	// temporary file if I want to use it

    /**
     * class that implements a psuedo interrupt.  Wake after URGENT_TIME milliseconds, more or less (no real-time guarantees)
     */
    static class UrgentMove extends TimerTask {
	public void run() {
	    System.out.println (URGENT_MOVE); // don't think; just move
	    
	    System.exit(0);	// exit with normal status
	}
    } // end UrgentMove

    /** 
     * class that implements a pair of integers
     */
    class Pair {
	int x;
	int y;

	/**
	 * constructor for a Pair
	 */
	Pair (int x, int y) {
	    this.x = x;
	    this.y = y;
	}

	/** accessor methods */
	int getX () { return this.x; }
	int getY () { return this.y; }
	
	/** mutation methods */
	void setX (int x) { this.x = x; }
	void setY (int y) { this.y = y; }
    }

    /**
     * Method to print the board
     */
    void printBoard () {
	int i;
	int j;
	for (i = 0; i < this.cols; i++) {
	    for (j = 0; j < this.rows; j++) {
		System.out.print (board[i][j] + " ");
	    } 
	    System.out.println();
	} 
    }

    /**
     * Method to make a move.  game state is stored in the class variables
     * 
     *
     * Method for you to implement. You want to make your modifications here.
     */
    Pair findMove () {
	Random r = new Random();
	int x = -1;
	int y = -1;

	if (this.debug == DEBUG) {
	    printBoard();
	}

	// get a random values for x and y as long as board[x][y] 
	try {
	while (x == -1 || y == -1 || board[x][y] != '-') {
	    x = r.nextInt(this.rows);
	    y = r.nextInt(this.cols);
	}
	} catch (Exception e) { ; }

	Pair action = new Pair(x,y);
	return (action);
    } // end of findMove

    /**
     * Method to read the input and store into appropriate data structures
     */
    int readInput () {
	// temporary variables
	String line;		
	String[] tokens;
	int lineNum = 0;

	int mode = UNKNOWN;	// mode of operation
	int x = 0;		// which x and y board position currently trying to fill
	int y = 0;

	// Read from standard input
	try {
	    BufferedReader in = new BufferedReader(new InputStreamReader (System.in));
	    while ((line = in.readLine()) != null) {
		lineNum++;
		// decide which mode of operation we are in depending on the first line of input
		if (lineNum == 1) {
		    if (line.equals("tagline")) { 
			mode = TAGLINE;
		    } else if (line.equals("email")) { 
			mode = EMAIL;
		    } else if (line.equals("move")) {
			mode = MOVE;
		    } else {
			throw new Exception ("Unknown mode of operation!");
		    }
		}
		
		// read data from standard input into data structures for manipulation later
		if (mode == MOVE) {
		    switch (lineNum) {
		    case 1: break;
		    case 2: tmpfile = line; 
			break;
		    case 3: 
			tokens = line.split(" ");
			turnNumber = Integer.parseInt(tokens[0]);
			mySymbol = Integer.parseInt(tokens[1]);
			break;
		    case 4: 
			tokens = line.split(" ");
			rows = Integer.parseInt(tokens[0]);
			cols = Integer.parseInt(tokens[1]);

			// build board
			board = new char[rows][cols];
			x = 0;
			break;
		    default:	// all board lines
			tokens = line.split(" +");
			int i;
			if (tokens[0].equals("")) { i = 1; } 
			else { i = 0; }
			for (y=0; i < tokens.length; i++, y++) {
			    board[x][y] = tokens[i].charAt(0);
			}
			x++;
		    }
		} 
	    }
	} catch (Exception e) {	// oops, something bad happened.  print the stack trace and exit.
	    e.printStackTrace();
	    System.exit(-1);
	}
	return mode;
    } // end of readInput

    /**
     * The main class to the work
     */
    public static void main (String[] args) {
	AgentHT00000X agent = new AgentHT00000X();

	Timer timer = new Timer();
	// timer.schedule (new UrgentMove(), URGENT_TIME);

	int mode = agent.readInput();

	switch (mode) {
	case TAGLINE:
	    System.out.println(tagline); 
	    break;
	case EMAIL:
	    System.out.println(email); 
	    break;
	case MOVE: 
	    Pair move = agent.findMove (); // get our move
	    System.out.println (move.getX() + " " + move.getY());
	    timer.cancel();
	    break;
	}
    } // end of main
}
